#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.4
visibility:           public
id:                   idris-1.3.4-32lkoTDHfPm3HXcr2yOcqc
key:                  idris-1.3.4-32lkoTDHfPm3HXcr2yOcqc
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  89aad49e18cbf97b70c0f6fcf02606b5
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.0.2/site-local/idris-1.3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/idris-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.4-32lkoTDHfPm3HXcr2yOcqc
extra-libraries:      gmp
depends:
    aeson-2.1.2.1-5RDZhERJnAA4H89g4WTdzv
    annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
    ansi-terminal-0.11.4-941itkoMzqP2HjyJtSkjHb
    ansi-wl-pprint-0.6.9-2uFUm4gN2lbAAo4Ze86TJx array-0.5.4.0
    async-2.2.5-2AzmtmK8Ht1K5YVHzqnMlN base-4.15.1.0
    base64-bytestring-1.2.1.0-DmjE4B5kPu75fN834AjqPB binary-0.8.8.0
    blaze-html-0.9.1.2-JT9mn2hMnf595zFx9EvPoy
    blaze-markup-0.8.3.0-CAd2GgzmqJsI2olKQ287Z bytestring-0.10.12.1
    cheapskate-0.1.1.2-3wQWBr9f0gr2NzBC9I45Sp
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2 filepath-1.4.2.1
    fingertree-0.1.5.0-17SEDmRcMOntDiNEABvqp
    fsnotify-0.4.0.0-EiW5SSGCnXEIc6oRaxSbnq haskeline-0.8.2
    ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
    libffi-0.2.1-DP5u3iTN0ykGYSlh8Owdy3
    megaparsec-9.5.0-LdFjCpmSswWFjxJT5JwBDf mtl-2.2.2
    network-3.1.4.0-FdTdnnvJv4pnhop8qDvVA
    optparse-applicative-0.17.1.0-AxEI8mDLbJi7Q5pwqU28ta
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB pretty-1.1.3.6
    process-1.6.13.2 regex-tdfa-1.3.2.2-EZ3lnAd3g4KFr62W9nn2hr
    safe-0.3.20-I3r2IsgJ6HyIplwNg1YNDT
    split-0.2.5-F85B58YbDNO5Z7070vmhpx
    terminal-size-0.3.4-35v8zhylKTKAMnavZT32Cm text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 uniplate-1.6.13-CwkSwwItGJCGTH85Ej922e
    unix-2.7.2.2 unordered-containers-0.2.20-F7LW31p7u1B2dWjdgteKaR
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.13.1.0-uzHHqo7lIz9I73C2bosU7
    vector-binary-instances-0.2.5.2-Dpn87tZwFQ1JCjf1wxljYW
    zip-archive-0.4.3-5oWU4MAQ7SWFCU7oQNqZ08

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

